@@ -40,12 +40,12 @@
 
 #include "enum-types.h"
 
-#include "gtkcustomfilter.h"
-#include "gtkfilterlistmodel.h"
-#include "gtkflattenlistmodel.h"
-
 #include <glib/gi18n.h>
-#include <libpeas/peas.h>
+#include <libpeas.h>
+
+#define LIBFEEDBACK_USE_UNSTABLE_API
+#include <libfeedback.h>
+
 
 /**
  * SECTION:manager
@@ -314,6 +314,13 @@ remove_call (CallsManager *self, CallsCall *call, gchar *reason, CallsOrigin *or
   g_timeout_add (DELAY_CALL_REMOVE_MS,
                  G_SOURCE_FUNC (on_remove_delayed),
                  data);
+
+  /* Notify that remote side hung up */
+  if (!calls_call_get_we_hung_up (call) && lfb_is_initted ()) {
+    LfbEvent *event = lfb_event_new ("phone-hangup");
+
+    lfb_event_trigger_feedback_async (event, NULL, NULL, NULL);
+  }
 }
 #undef DELAY_CALL_REMOVE_MS
 
@@ -451,12 +458,8 @@ calls_manager_finalize (GObject *object)
 {
   CallsManager *self = CALLS_MANAGER (object);
 
-  g_clear_object (&self->origins);
   g_clear_object (&self->contacts_provider);
 
-  g_clear_pointer (&self->origins_by_protocol, g_hash_table_unref);
-  g_clear_pointer (&self->dial_actions_by_protocol, g_hash_table_unref);
-
   G_OBJECT_CLASS (calls_manager_parent_class)->finalize (object);
 }
 
@@ -599,7 +602,7 @@ calls_manager_init (CallsManager *self)
   self->state_flags = CALLS_MANAGER_FLAGS_UNKNOWN;
 
   self->origins = g_list_store_new (G_TYPE_LIST_MODEL); /* list of lists */
-  self->origins_flat = gtk_flatten_list_model_new (CALLS_TYPE_ORIGIN, G_LIST_MODEL (self->origins));
+  self->origins_flat = gtk_flatten_list_model_new (G_LIST_MODEL (self->origins));
 
   providers = calls_plugin_manager_get_providers (plugin_manager);
   g_signal_connect_object (providers,
@@ -616,8 +619,8 @@ calls_manager_init (CallsManager *self)
                                                      g_object_unref);
 
   for (guint i = 0; i < G_N_ELEMENTS (protocols); i++) {
-    g_autoptr (GtkFilter) filter =
-      gtk_custom_filter_new (match_origin_supports_protocol, (gpointer) protocols[i], NULL);
+    GtkFilter* filter =
+      GTK_FILTER (gtk_custom_filter_new (match_origin_supports_protocol, (gpointer) protocols[i], NULL));
     GtkFilterListModel *f_list =
       gtk_filter_list_model_new (G_LIST_MODEL (self->origins_flat), filter);
 
